Algorithm

Enum Algorithm 

pub enum Algorithm {
    Myers,
    MyersLinearSpace,
    Patience,
}
The core shortest-edit-script algorithm.

Variants



Myers

Myers’ greedy algorithm, switching to the linear-space variant above LINEAR_SPACE_THRESHOLD items.



MyersLinearSpace

Always use Myers’ linear-space (middle snake) variant.



Patience

Patience diff: anchor on items that are unique in both inputs, Myers in between. Not guaranteed minimal, but often reads better for code.