pub enum ScriptError {
BadA(usize),
BadB(usize),
MissingA(usize),
MissingB(usize),
EqualOutOfOrder(usize),
KeyMismatch {
a: usize,
b: usize,
},
}Expand description
Why an edit script is not a valid transformation of a into b.
Variants
BadA(usize)
An index of a is used more than once or out of range.
BadB(usize)
An index of b is used more than once, out of range, or out of order.
MissingA(usize)
An index of a is not accounted for.
MissingB(usize)
An index of b is not produced.
EqualOutOfOrder(usize)
Equal ops are not in increasing a order.
KeyMismatch
An Equal or Move pairs items whose keys differ.