pub fn validate(ops: &[Op], n: usize, m: usize) -> Result<(), ScriptError>Expand description
Checks the structure of a script for inputs of length n and m: every index of each
input is used exactly once, b indices appear in increasing order, and Equal ops keep
a order.